@@ -26,7 +26,9 @@ class PlotConfigWidget(QWidget, gui.OWComponent):
     plot_type = 'line'
 
     def __init__(self, owwidget, ax, varmodel):
-        super().__init__(owwidget)
+        QWidget.__init__(self, owwidget)
+        gui.OWComponent.__init__(self)
+
         self.ax = ax
         self.view = view = QListView(self, selectionMode=QTreeWidget.ExtendedSelection,)
         view.setModel(varmodel)
@@ -62,10 +64,17 @@ class PlotConfigWidget(QWidget, gui.OWComponent):
                      callback=lambda: self.sigLogarithmic.emit(ax, self.is_logarithmic))
         box.addWidget(view)
 
+    # This is here because sometimes enterEvent/leaveEvent below were called
+    # before the constructor set button_close appropriately. I have no idea.
+    button_close = None
+
     def enterEvent(self, event):
-        self.button_close.setVisible(True)
+        if self.button_close:
+            self.button_close.setVisible(True)
+
     def leaveEvent(self, event):
-        self.button_close.setVisible(False)
+        if self.button_close:
+            self.button_close.setVisible(False)
 
     def selection_changed(self):
         selection = [mi.model()[mi.row()]
